==> indigitall_flutter_plugin-2.2.0.tar.gz: android/src/main/kotlin/com/indigitall/indigitall_flutter_plugin/utils/PushParse.kt <==
package com.indigitall.indigitall_flutter_plugin.utils

import com.indigitall.android.commons.models.CoreAction
import com.indigitall.android.push.models.*
import org.json.JSONArray
import org.json.JSONException
import org.json.JSONObject

object PushParse {

    private val CALLBACK_GET_PUSH = "callbackgetPush"

    fun stringToMap(key: String, value: String): Map<*, *>{
        val map: MutableMap<String, String> = HashMap()
        map[key] = value
        return map
    }

    fun topicToMap(key: String, value: ArrayList<Map<*, *>>): Map<*, *>{
        val map: MutableMap<String, ArrayList<Map<*, *>>> = HashMap()
        map[key] = value
        return map
    }

    fun mapFromDevice(device: Device, key: String): Map<String, Map<*,*>> {
        val MAP_ENABLE = "enable"
        val MAP_DEVICE_ID = "deviceId"
        val MAP_PUSH_TOKEN = "pushToken"
        val MAP_PLATFORM = "platform"
        val MAP_VERSION = "version"
        val MAP_PRODUCT_NAME = "productName"
        val MAP_PRODUCT_VERSION = "productVersion"
        val MAP_OS_NAME = "osName"
        val MAP_OS_VERSION = "osVersion"
        val MAP_DEVICE_BRAND = "deviceBrand"
        val MAP_DEVICE_MODEL = "deviceModel"
        val MAP_OPERATOR = "operator"
        val MAP_DEVICE_TYPE = "deviceType"
        val MAP_APP_VERSION = "appVersion"
        val MAP_LOCALE = "locale"
        val MAP_TIME_ZONE = "timeZone"
        val MAP_TIME_OFFSET = "timeOffset"
        val MAP_EXTERNAL_APPS = "externalApps"
        val MAP_EXTERNAL_CODE = "externalCode"
        val map: MutableMap<String, String> = HashMap()

        device.enabled?.let{map[MAP_ENABLE] = it.toString()}
        device.deviceId?.let{map[MAP_DEVICE_ID] = it}
        device.pushToken?.let{map[MAP_PUSH_TOKEN] = it}
        device.platform?.let{map[MAP_PLATFORM] = it}
        device.version?.let{map[MAP_VERSION] = it}
        device.productName?.let{map[MAP_PRODUCT_NAME] = it}
        device.productVersion?.let{map[MAP_PRODUCT_VERSION] = it}
        device.osName?.let{map[MAP_OS_NAME] = it}
        device.osVersion?.let{map[MAP_OS_VERSION] = it}
        device.deviceBrand?.let{map[MAP_DEVICE_BRAND] = it}
        device.deviceModel?.let{map[MAP_DEVICE_MODEL] = it}
        device.operator?.let{map[MAP_OPERATOR] = it}
        device.deviceType?.let{map[MAP_DEVICE_TYPE] = it}
        device.appVersion?.let{map[MAP_APP_VERSION] = it}
        device.locale?.let{map[MAP_LOCALE] = it}
        device.timeZone?.let{map[MAP_TIME_ZONE] = it}
        device.timeOffset?.let{map[MAP_TIME_OFFSET] = it.toString()}
        device.externalCode?.let{map[MAP_EXTERNAL_CODE] = device.externalCode.toString()}
        device.externalApps?.let{map[MAP_EXTERNAL_APPS] = jsonArrayFromExternalApps(it).toString()}

        val deviceMap: MutableMap<String, Map<*,*>> = HashMap()
        deviceMap[key] = map
        return deviceMap
    }

    fun jsonArrayFromExternalApps(externalApps: Array<ExternalApp?>): JSONArray {
        val MAP_ID = "id"
        val MAP_NAME = "name"
        val MAP_CODE = "code"
        val array = JSONArray()
        if (externalApps != null) {
            try {
                for (app in externalApps) {
                    val map : MutableMap<String, String> = HashMap()
                    app?.id?.let{map[MAP_ID] = it.toString()}
                    app?.name?.let{map[MAP_NAME] = it}
                    app?.androidCode?.let{map[MAP_CODE] = it}
                    array.put(map)
                }
            } catch (ex: JSONException) {
                ex.printStackTrace()
            }
        }
        return array
    }

    fun parseTopicArray(params: JSONArray?): Array<String?> {
        var topics = arrayOf<String?>()
        try {
            params?.let{
                if (it.length() > 0) {
                    topics = arrayOfNulls(it.length())
                    for (i in 0 until it.length()) {
                        topics[i] = it.getString(i)
                    }
                }
            }
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return topics
    }


    fun mapFromTopic(topic: Topic): Map<*, *> {
        val MAP_CODE = "code"
        val MAP_NAME = "name"
        val MAP_VISIBLE = "visible"
        val MAP_SUBSCRIBED = "subscribed"
        val MAP_PARENT_CODE = "parentCode"
        val map : MutableMap<String, String> = HashMap()
        try {
            topic.code?.let{map[MAP_CODE] = it}
            topic.name?.let{map[MAP_NAME] = it}
            topic.isVisible()?.let{map[MAP_VISIBLE] = it.toString()}
            topic.isSubscribed()?.let{map[MAP_SUBSCRIBED] = it.toString()}
            topic.parentCode?.let{map[MAP_PARENT_CODE] = it}
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return map
    }

    fun listFromTopicArray(topics: Array<Topic>): ArrayList<Map<*, *>> {
        val list = arrayListOf<Map<*, *>>()
        for (i in topics.indices){
            list.add(mapFromTopic(topics[i]))
        }
        return list
    }


    fun mapFromPush(push: Push): Map<*, *> {
        val MAP_ID = "id"
        val MAP_APP_KEY = "appKey"
        val MAP_TITLE = "title"
        val MAP_BODY = "body"
        val MAP_ICON = "icon"
        val MAP_IMAGE = "image"
        val MAP_GIF = "gif"
        val MAP_LAYOUT = "layout"
        val MAP_DATA = "data"
        val MAP_SILENT = "silent"
        val MAP_SECURE_DATA = "securedData"
        val MAP_ACTION = "action"
        val MAP_BUTTONS = "buttons"
        val MAP_SENDING_ID = "sendingId"
        val MAP_CAMPAIGN_ID = "CampaignId"
        val MAP_PUSH_ID = "pushId"
        val json = JSONObject()
        try {
            push.id?.let{
                json.put(MAP_ID , push.id.toString())
                json.put(MAP_PUSH_ID, push.id.toString())
            }
            push.appKey?.let{json.put(MAP_APP_KEY, it)}
            push.title?.let{json.put(MAP_TITLE, it)}
            push.body?.let{json.put(MAP_BODY, it)}
            push.icon?.let{json.put(MAP_ICON, it)}
            push.image?.let{json.put(MAP_IMAGE, it)}
            push.gif?.let{json.put(MAP_GIF, it.toString())}
            push.layout?.let{json.put(MAP_LAYOUT,it.toString())}
            push.data?.let{json.put(MAP_DATA, it)}
            push.silent?.let{json.put(MAP_SILENT, it.toString())}
            push.action?.let{json.put(MAP_ACTION, mapFromAction(it).toString())}
            push.securedData?.let{json.put(MAP_SECURE_DATA, it)}
            push.sendingId?.let{json.put(MAP_SENDING_ID, it)}
            push.campaignId?.let{json.put(MAP_CAMPAIGN_ID, it)}

            push.buttons?.let{
                var pushButton = ArrayList<JSONObject>()
                for (i in it.indices) {
                    val pushButtonMap = it[i]
                    pushButton.add(mapFromPushButtons(pushButtonMap))
                }
                json.put(MAP_BUTTONS, pushButton.toString())
            }
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }

        val pushMap: MutableMap<String, String> = HashMap()
        pushMap[CALLBACK_GET_PUSH] = json.toString()
        return pushMap
    }

    fun mapFromAction(pushAction: CoreAction): JSONObject {
        val MAP_DESTROY = "destroy"
        val MAP_TOPICS = "topics"
        val MAP_TYPE = "type"
        val MAP_TYPE_APP = "app"
        val MAP_TYPE_URL = "url"
        val MAP_TYPE_CALL = "call"
        val MAP_TYPE_MARKET = "market"
        val MAP_TYPE_SHARE = "share"
        val MAP_TYPE_WEBVIEW = "webview"

        val map = JSONObject()
        try {
            pushAction.isDestroy()?.let{map.put(MAP_DESTROY, it.toString())}
            pushAction.topics?.let{map.put(MAP_TOPICS,it.toString())}
            pushAction.type?.let{map.put(MAP_TYPE, it.toString())}
            pushAction.app?.let{map.put(MAP_TYPE_APP, it)}
            pushAction.url?.let{map.put(MAP_TYPE_URL, it)}
            pushAction.call?.let{map.put(MAP_TYPE_CALL, it)}
            pushAction.market?.let{map.put(MAP_TYPE_MARKET, it)}
            pushAction.share?.let{map.put(MAP_TYPE_SHARE, it)}
            pushAction.webview?.let{map.put(MAP_TYPE_WEBVIEW, it)}
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return map
    }

    fun mapFromPushButtons(pushButton: PushButton): JSONObject {
        val MAP_LABEL = "label"
        val MAP_ACTION = "action"
        val MAP_TOPICS = "topics"
        val map = JSONObject()
        try {
            pushButton.label?.let{map.put(MAP_LABEL, it)}
            pushButton.action?.let{map.put(MAP_ACTION, mapFromAction(it).toString())}
            pushButton.topics?.let{
                if (it.count() > 0){
                    map.put(MAP_TOPICS, it.toString())
                }
            }
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return map
    }
}

==> indigitall_flutter_plugin-2.5.1.tar.gz: android/src/main/kotlin/com/indigitall/indigitall_flutter_plugin/utils/PushParse.kt <==
package com.indigitall.indigitall_flutter_plugin.utils

import com.indigitall.android.commons.models.CoreAction
import com.indigitall.android.push.models.*
import org.json.JSONArray
import org.json.JSONException
import org.json.JSONObject

object PushParse {

    private val CALLBACK_GET_PUSH = "callbackgetPush"

    fun stringToMap(key: String, value: String): Map<*, *>{
        val map: MutableMap<String, String> = HashMap()
        map[key] = value
        return map
    }

    fun topicToMap(key: String, value: ArrayList<Map<*, *>>): Map<*, *>{
        val map: MutableMap<String, ArrayList<Map<*, *>>> = HashMap()
        map[key] = value
        return map
    }

    fun mapFromDevice(device: Device, key: String): Map<String, Map<*,*>> {
        val MAP_ENABLE = "enable"
        val MAP_DEVICE_ID = "deviceId"
        val MAP_PUSH_TOKEN = "pushToken"
        val MAP_PLATFORM = "platform"
        val MAP_VERSION = "version"
        val MAP_PRODUCT_NAME = "productName"
        val MAP_PRODUCT_VERSION = "productVersion"
        val MAP_OS_NAME = "osName"
        val MAP_OS_VERSION = "osVersion"
        val MAP_DEVICE_BRAND = "deviceBrand"
        val MAP_DEVICE_MODEL = "deviceModel"
        val MAP_OPERATOR = "operator"
        val MAP_DEVICE_TYPE = "deviceType"
        val MAP_APP_VERSION = "appVersion"
        val MAP_LOCALE = "locale"
        val MAP_TIME_ZONE = "timeZone"
        val MAP_TIME_OFFSET = "timeOffset"
        val MAP_EXTERNAL_APPS = "externalApps"
        val MAP_EXTERNAL_CODE = "externalCode"
        val map: MutableMap<String, String> = HashMap()

        device.enabled?.let{map[MAP_ENABLE] = it.toString()}
        device.deviceId?.let{map[MAP_DEVICE_ID] = it}
        device.pushToken?.let{map[MAP_PUSH_TOKEN] = it}
        device.platform?.let{map[MAP_PLATFORM] = it}
        device.version?.let{map[MAP_VERSION] = it}
        device.productName?.let{map[MAP_PRODUCT_NAME] = it}
        device.productVersion?.let{map[MAP_PRODUCT_VERSION] = it}
        device.osName?.let{map[MAP_OS_NAME] = it}
        device.osVersion?.let{map[MAP_OS_VERSION] = it}
        device.deviceBrand?.let{map[MAP_DEVICE_BRAND] = it}
        device.deviceModel?.let{map[MAP_DEVICE_MODEL] = it}
        device.operator?.let{map[MAP_OPERATOR] = it}
        device.deviceType?.let{map[MAP_DEVICE_TYPE] = it}
        device.appVersion?.let{map[MAP_APP_VERSION] = it}
        device.locale?.let{map[MAP_LOCALE] = it}
        device.timeZone?.let{map[MAP_TIME_ZONE] = it}
        device.timeOffset?.let{map[MAP_TIME_OFFSET] = it.toString()}
        device.externalCode?.let{map[MAP_EXTERNAL_CODE] = device.externalCode.toString()}
        device.externalApps?.let{map[MAP_EXTERNAL_APPS] = jsonArrayFromExternalApps(it).toString()}

        val deviceMap: MutableMap<String, Map<*,*>> = HashMap()
        deviceMap[key] = map
        return deviceMap
    }

    fun jsonArrayFromExternalApps(externalApps: Array<ExternalApp?>): JSONArray {
        val MAP_ID = "id"
        val MAP_NAME = "name"
        val MAP_CODE = "code"
        val array = JSONArray()
        if (externalApps != null) {
            try {
                for (app in externalApps) {
                    val map : MutableMap<String, String> = HashMap()
                    app?.id?.let{map[MAP_ID] = it.toString()}
                    app?.name?.let{map[MAP_NAME] = it}
                    app?.androidCode?.let{map[MAP_CODE] = it}
                    array.put(map)
                }
            } catch (ex: JSONException) {
                ex.printStackTrace()
            }
        }
        return array
    }

    fun parseTopicArray(params: JSONArray?): Array<String?> {
        var topics = arrayOf<String?>()
        try {
            params?.let{
                if (it.length() > 0) {
                    topics = arrayOfNulls(it.length())
                    for (i in 0 until it.length()) {
                        topics[i] = it.getString(i)
                    }
                }
            }
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return topics
    }


    fun mapFromTopic(topic: Topic): Map<*, *> {
        val MAP_CODE = "code"
        val MAP_NAME = "name"
        val MAP_VISIBLE = "visible"
        val MAP_SUBSCRIBED = "subscribed"
        val MAP_PARENT_CODE = "parentCode"
        val map : MutableMap<String, String> = HashMap()
        try {
            topic.code?.let{map[MAP_CODE] = it}
            topic.name?.let{map[MAP_NAME] = it}
            topic.isVisible()?.let{map[MAP_VISIBLE] = it.toString()}
            topic.isSubscribed()?.let{map[MAP_SUBSCRIBED] = it.toString()}
            topic.parentCode?.let{map[MAP_PARENT_CODE] = it}
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return map
    }

    fun listFromTopicArray(topics: Array<Topic>): ArrayList<Map<*, *>> {
        val list = arrayListOf<Map<*, *>>()
        for (i in topics.indices){
            list.add(mapFromTopic(topics[i]))
        }
        return list
    }


    fun mapFromPush(push: Push): Map<*, *> {
        val MAP_ID = "id"
        val MAP_APP_KEY = "appKey"
        val MAP_TITLE = "title"
        val MAP_BODY = "body"
        val MAP_ICON = "icon"
        val MAP_IMAGE = "image"
        val MAP_GIF = "gif"
        val MAP_LAYOUT = "layout"
        val MAP_DATA = "data"
        val MAP_SILENT = "silent"
        val MAP_SECURE_DATA = "securedData"
        val MAP_ACTION = "action"
        val MAP_BUTTONS = "buttons"
        val MAP_SENDING_ID = "sendingId"
        val MAP_CAMPAIGN_ID = "campaignId"
        val MAP_APPLICATION_ID = "applicationId"
        val MAP_SEND_EVENT_ACK = "SendEventAck"
        val MAP_PUSH_ID = "pushId"
        val json = JSONObject()
        try {
            push.id?.let{
                json.put(MAP_ID , push.id.toString())
                json.put(MAP_PUSH_ID, push.id.toString())
            }
            push.appKey?.let{json.put(MAP_APP_KEY, it)}
            push.title?.let{json.put(MAP_TITLE, it)}
            push.body?.let{json.put(MAP_BODY, it)}
            push.icon?.let{json.put(MAP_ICON, it)}
            push.image?.let{json.put(MAP_IMAGE, it)}
            push.gif?.let{json.put(MAP_GIF, it.toString())}
            push.layout?.let{json.put(MAP_LAYOUT,it.toString())}
            push.data?.let{json.put(MAP_DATA, it)}
            push.silent?.let{json.put(MAP_SILENT, it.toString())}
            push.action?.let{json.put(MAP_ACTION, mapFromAction(it).toString())}
            push.securedData?.let{json.put(MAP_SECURE_DATA, it)}
            push.sendingId?.let{json.put(MAP_SENDING_ID, it)}
            push.campaignId?.let{json.put(MAP_CAMPAIGN_ID, it)}
            push.applicationId?.let{json.put(MAP_APPLICATION_ID, it)}
            push.sendEventAck?.let{json.put(MAP_SEND_EVENT_ACK, it)}

            push.buttons?.let{
                var pushButton = ArrayList<JSONObject>()
                for (i in it.indices) {
                    val pushButtonMap = it[i]
                    pushButton.add(mapFromPushButtons(pushButtonMap))
                }
                json.put(MAP_BUTTONS, pushButton.toString())
            }
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }

        val pushMap: MutableMap<String, String> = HashMap()
        pushMap[CALLBACK_GET_PUSH] = json.toString()
        return pushMap
    }

    fun mapFromAction(pushAction: CoreAction): JSONObject {
        val MAP_DESTROY = "destroy"
        val MAP_TOPICS = "topics"
        val MAP_TYPE = "type"
        val MAP_TYPE_APP = "app"
        val MAP_TYPE_URL = "url"
        val MAP_TYPE_CALL = "call"
        val MAP_TYPE_MARKET = "market"
        val MAP_TYPE_SHARE = "share"
        val MAP_TYPE_WEBVIEW = "webview"

        val map = JSONObject()
        try {
            pushAction.isDestroy()?.let{map.put(MAP_DESTROY, it.toString())}
            pushAction.topics?.let{map.put(MAP_TOPICS,it.toString())}
            pushAction.type?.let{map.put(MAP_TYPE, it.toString())}
            pushAction.app?.let{map.put(MAP_TYPE_APP, it)}
            pushAction.url?.let{map.put(MAP_TYPE_URL, it)}
            pushAction.call?.let{map.put(MAP_TYPE_CALL, it)}
            pushAction.market?.let{map.put(MAP_TYPE_MARKET, it)}
            pushAction.share?.let{map.put(MAP_TYPE_SHARE, it)}
            pushAction.webview?.let{map.put(MAP_TYPE_WEBVIEW, it)}
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return map
    }

    fun mapFromPushButtons(pushButton: PushButton): JSONObject {
        val MAP_LABEL = "label"
        val MAP_ACTION = "action"
        val MAP_TOPICS = "topics"
        val map = JSONObject()
        try {
            pushButton.label?.let{map.put(MAP_LABEL, it)}
            pushButton.action?.let{map.put(MAP_ACTION, mapFromAction(it).toString())}
            pushButton.topics?.let{
                if (it.count() > 0){
                    map.put(MAP_TOPICS, it.toString())
                }
            }
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return map
    }
}
